==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/StorageTransferJobTransferSpecTransferOptionsOutputReference.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:06.686Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptionsOutputReference")
public class StorageTransferJobTransferSpecTransferOptionsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected StorageTransferJobTransferSpecTransferOptionsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StorageTransferJobTransferSpecTransferOptionsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public StorageTransferJobTransferSpecTransferOptionsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteObjectsFromSourceAfterTransfer() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteObjectsUniqueInSink() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteObjectsUniqueInSink", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOverwriteObjectsAlreadyExistingInSink() {
        software.amazon.jsii.Kernel.call(this, "resetOverwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsFromSourceAfterTransferInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransferInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsUniqueInSinkInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSinkInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getOverwriteObjectsAlreadyExistingInSinkInput() {
        return software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSinkInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsFromSourceAfterTransfer(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsFromSourceAfterTransfer", java.util.Objects.requireNonNull(value, "deleteObjectsFromSourceAfterTransfer is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsFromSourceAfterTransfer(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsFromSourceAfterTransfer", java.util.Objects.requireNonNull(value, "deleteObjectsFromSourceAfterTransfer is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDeleteObjectsUniqueInSink() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsUniqueInSink(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsUniqueInSink", java.util.Objects.requireNonNull(value, "deleteObjectsUniqueInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsUniqueInSink(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsUniqueInSink", java.util.Objects.requireNonNull(value, "deleteObjectsUniqueInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
        return software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setOverwriteObjectsAlreadyExistingInSink(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "overwriteObjectsAlreadyExistingInSink", java.util.Objects.requireNonNull(value, "overwriteObjectsAlreadyExistingInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setOverwriteObjectsAlreadyExistingInSink(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "overwriteObjectsAlreadyExistingInSink", java.util.Objects.requireNonNull(value, "overwriteObjectsAlreadyExistingInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/StorageTransferJobTransferSpecTransferOptionsOutputReference.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:23.497Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptionsOutputReference")
public class StorageTransferJobTransferSpecTransferOptionsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected StorageTransferJobTransferSpecTransferOptionsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StorageTransferJobTransferSpecTransferOptionsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public StorageTransferJobTransferSpecTransferOptionsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteObjectsFromSourceAfterTransfer() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteObjectsUniqueInSink() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteObjectsUniqueInSink", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOverwriteObjectsAlreadyExistingInSink() {
        software.amazon.jsii.Kernel.call(this, "resetOverwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOverwriteWhen() {
        software.amazon.jsii.Kernel.call(this, "resetOverwriteWhen", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsFromSourceAfterTransferInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransferInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsUniqueInSinkInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSinkInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getOverwriteObjectsAlreadyExistingInSinkInput() {
        return software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSinkInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getOverwriteWhenInput() {
        return software.amazon.jsii.Kernel.get(this, "overwriteWhenInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsFromSourceAfterTransfer(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsFromSourceAfterTransfer", java.util.Objects.requireNonNull(value, "deleteObjectsFromSourceAfterTransfer is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsFromSourceAfterTransfer(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsFromSourceAfterTransfer", java.util.Objects.requireNonNull(value, "deleteObjectsFromSourceAfterTransfer is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getDeleteObjectsUniqueInSink() {
        return software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsUniqueInSink(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsUniqueInSink", java.util.Objects.requireNonNull(value, "deleteObjectsUniqueInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setDeleteObjectsUniqueInSink(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "deleteObjectsUniqueInSink", java.util.Objects.requireNonNull(value, "deleteObjectsUniqueInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
        return software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setOverwriteObjectsAlreadyExistingInSink(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        software.amazon.jsii.Kernel.set(this, "overwriteObjectsAlreadyExistingInSink", java.util.Objects.requireNonNull(value, "overwriteObjectsAlreadyExistingInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setOverwriteObjectsAlreadyExistingInSink(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "overwriteObjectsAlreadyExistingInSink", java.util.Objects.requireNonNull(value, "overwriteObjectsAlreadyExistingInSink is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getOverwriteWhen() {
        return software.amazon.jsii.Kernel.get(this, "overwriteWhen", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setOverwriteWhen(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "overwriteWhen", java.util.Objects.requireNonNull(value, "overwriteWhen is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.StorageTransferJobTransferSpecTransferOptions value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
